@@ -9,7 +9,7 @@ Changes vector s0:
     s0: Equal to the elements with index ij of eq 17 [1].
 
 References
-[1] Hamed KH (2008) Trend detection in hydrologic data: The MannKendall trend
+[1] Hamed KH (2008) Trend detection in hydrologic data: The Mann-Kendall trend
     test under the scaling hypothesis. Journal of Hydrology 349(3-4):350-363.
     doi:10.1016/j.jhydrol.2007.11.009
 *******************************************************************************/
